# Проект Kafka Event Parser

Этот проект предназначен для парсинга событий и отправки их в Kafka.

## Установка

### Автоматически

```sh
pip install pydatamining
```

### Вручную

1. Клонируйте репозиторий в папку с проектом:
    ```sh
    git clone https://github.com/notickets/pydatamining
    ```

2. Создайте виртуальное окружение:
    ```sh
    python3 -m venv venv
    ```
3. Активируйте виртуальное окружение:
    ```sh
    source venv/bin/activate
    ```
4. Установите зависимости:
    ```sh
    pip install -r pydatamining/requirements.txt
    ```
